@@ -5,6 +5,7 @@ __all__ = [
     "heap",
     "build",
     "build2",
+    "get_index",
     "get_parent",
     "__version__",
 ]
@@ -511,7 +512,7 @@ class Node:
 
         def scale_x(x: int, y: int) -> float:
             diff = tree_height - y
-            x = 2 ** (diff + 1) * x + 2 ** diff - 1
+            x = 2 ** (diff + 1) * x + 2**diff - 1
             return 1 + node_radius + scale * x / 2
 
         def scale_y(y: int) -> float:
@@ -561,7 +562,7 @@ class Node:
             y += 1
 
         return _SVG_XML_TEMPLATE.format(
-            width=scale * (2 ** tree_height),
+            width=scale * (2**tree_height),
             height=scale * (2 + tree_height),
             body="\n".join(xml),
         )
@@ -1832,7 +1833,7 @@ def _generate_random_leaf_count(height: int) -> int:
     :return: Random leaf count.
     :rtype: int
     """
-    max_leaf_count = 2 ** height
+    max_leaf_count = 2**height
     half_leaf_count = max_leaf_count // 2
 
     # A very naive way of mimicking normal distribution
@@ -2015,7 +2016,7 @@ def _get_tree_properties(root: Node) -> NodeProperties:
         size=size,
         is_max_heap=is_complete and is_descending,
         is_min_heap=is_complete and is_ascending,
-        is_perfect=leaf_count == 2 ** max_leaf_depth,
+        is_perfect=leaf_count == 2**max_leaf_depth,
         is_strict=is_strict,
         is_complete=is_complete,
         leaf_count=leaf_count,
@@ -2026,6 +2027,75 @@ def _get_tree_properties(root: Node) -> NodeProperties:
     )
 
 
+def get_index(root: Node, descendent: Node) -> int:
+    """Return the level-order_ index given the root and a possible descendent.
+
+    .. _level-order:
+        https://en.wikipedia.org/wiki/Tree_traversal#Breadth-first_search
+
+    :return: Level-order index of the descendent relative to the root node.
+    :rtype: int
+    :raise binarytree.exceptions.NodeTypeError: If root or descendent is
+        not an instance of :class:`binarytree.Node`.
+    :raise binarytree.exceptions.NodeReferenceError: If given a node that is
+        not a root/descendent.
+
+    **Example**:
+
+    .. doctest::
+
+        >>> from binarytree import Node, get_index
+        >>>
+        >>> root = Node(1)
+        >>> root.left = Node(2)
+        >>> root.right = Node(3)
+        >>> root.left.right = Node(4)
+        >>>
+        >>> get_index(root, root.left)
+        1
+        >>> get_index(root, root.right)
+        2
+        >>> get_index(root, root.left.right)
+        4
+        >>> get_index(root.left, root.right)
+        Traceback (most recent call last):
+         ...
+        NodeReferenceError: given nodes are not in the same tree
+    """
+    if root is None:
+        raise NodeTypeError("root must be a Node instance")
+
+    if descendent is None:
+        raise NodeTypeError("descendent must be a Node instance")
+
+    current_nodes: List[Optional[Node]] = [root]
+    current_index = 0
+    has_more_nodes = True
+
+    while has_more_nodes:
+        has_more_nodes = False
+        next_nodes: List[Optional[Node]] = []
+
+        for node in current_nodes:
+            if node is not None and node is descendent:
+                return current_index
+
+            if node is None:
+                next_nodes.append(None)
+                next_nodes.append(None)
+            else:
+                next_nodes.append(node.left)
+                next_nodes.append(node.right)
+                if node.left is not None or node.right is not None:
+                    has_more_nodes = True
+
+            current_index += 1
+
+        current_nodes = next_nodes
+
+    raise NodeReferenceError("given nodes are not in the same tree")
+
+
 def get_parent(root: Node, child: Node) -> Optional[Node]:
     """Search the binary tree and return the parent of given child.
 
@@ -2416,7 +2486,7 @@ def heap(
 
     if not is_perfect:
         # Randomly cut some of the leaf nodes away
-        random_cut = random.randint(2 ** height, len(values))
+        random_cut = random.randint(2**height, len(values))
         values = values[:random_cut]
 
     if is_max:
